
/*
Taken from IRAF (http://iraf.noao.edu)
*/
#include "asttimes.h"

double
ast_date_to_epoch (int year, int month, int day, double ut)
{

   double jd;
   double epoch;

   jd = ast_date_to_julday (year, month, day, ut);
   epoch = J2000 + (jd - JD2000) / JYEAR;
   
   return epoch;

}

double
ast_date_to_julday (int year, int month, int day, double gmt)
{
   double jd;
   double y, m, d;
   if (year < 1900)
      y = 1900 + (double)year;
   else
      y = (double)year;

   //m = (double)month + 1;
   if (month > 2)
      m = (double)(month + 1);
   else
   {
      m = (double)(month + 13);
      y = y - 1;
   }

   d = (double)day;

   jd = (double)((int)(JYEAR * y)) + (double)((int)(30.6001 * m)) + d + 1720995;
   if ((d + 31 * (m + 12 * y)) >= 588829)
   {
      d = (double)((int)(y/100));
      m = (double)((int)(y/400));
      jd = jd + 2 - d + m;
   }
   jd = jd - 0.5 + (double)((int)(gmt * 360000 + 0.5)) / 360000 / 24;
   return jd;

}

double
ast_julday (double epoch)
{
   double jd;
   jd = JD2000 + (epoch - J2000) * JYEAR;
   return jd;
}

double
ast_mst (double epoch, double longitude)
{
   double jd, ut, t, st;
   /* Kitt Peak is 111.6 */

   jd = ast_julday(epoch);
   ut = (jd - (double)((int)(jd)) - 0.5) * 24.0;
   t = (jd - 2451545.0) / 36525.0;

   st = 24110.54841 + t * (8640184.812866 + t * (0.093104 - t * 6.2e-6));

   st = modulo((st / 3600.0 + ut - longitude / 15.0),24);

   if (st < 0)
      st = st + 24;

   return (st);

}

double modulo (double lhs, int rhs)
{

   double value;
   int modulo;
   int l,r;
   l = (int)lhs;
   r = (int)rhs;
   value = lhs - l;
   value = value + rhs - r;
   modulo = l%r;
   value += modulo;
   return value;

}


